#!/bin/sh 

# Signal handler.
SignalTrap()
{
	echo "Received signal.  Update aborting."
	exit 1
}

# Set Signal Trap
trap SignalTrap INT QUIT TERM ABRT STOP

error=0
PACKAGE=$(basename "$0" ".sh").tar.gz
IMAGEPARTSIZE=$(df -h | awk '/hd0t180/ { sub("(\\.[0-9]+)?G$","",$2); print $2}')

LANGUAGE=enu
case $(awk -F "=" '/^systemLanguage/ { print $2 }' /fs/rwdata/ALPersistence/SourceSettings.ini) in
	7) LANGUAGE=frc;;
	9) LANGUAGE=spm;;
esac

# Enforce SYNC Version is not 1.x
grep -q "SYNCGen3.0_1" /fs/mp/Version.inf
if (( $? != 0 ));
then
	echo "SUCCESS: SYNC 3 Version 1.x not detected. Update is permitted."
else
	echo "FAIL: SYNC 3 Version 1.x detected. Exiting with no change."
	error=1
fi

# Enforce module contains sufficient space.
if [ "$IMAGEPARTSIZE" -gt 16 ];
then
	echo "SUCCESS: NAV module detected."
else
	echo "FAIL: NAV module not detected."
	error=1
fi

if (( $error != 0 )); then
	slay APP_SUM
	slay NAV_Manager
	slay fordhmi
	slay HMI_AL
	display_image -file=/tmp/error_msg_${LANGUAGE}.png -display=2 &

	find /fs/images/ivsu_* -name "*.lst*" -remove!
	find /fs/images/ivsu_* -name "*.tar.gz" -remove!
	sync
	sync

	while [ -e /fs/usb0 ]; do
		sleep 1
	done

	shutdown

fi

exit $error



